import { RouteRecordRaw } from 'vue-router';

export const dynamicRoutes: Array<RouteRecordRaw> = [

	{
		path: '/',
		name: '/',
		component: () => import('/@/layout/index.vue'),
		redirect: '/home',
		meta: {
			isKeepAlive: true,
		},
		children: [
			{
				path: '/home',
				name: 'home',
				component: () => import('/@/views/home/index.vue'),
				meta: {
					title: 'message.router.home',
					isLink: '',
					isHide: false,
					isKeepAlive: true,
					isAffix: true,
					isIframe: false,
					roles: ['admin', 'common'],
					icon: 'iconfont icon-shouye',
					button:'121231'
				}
			// },
			// {
			// 	path: '/layoutPage',
			// 	name: 'layoutPage',
			// 	component: () => import('/@/views/layoutPage/index.vue'),
			// 	meta: {
			// 		title: 'message.router.layoutPage',
			// 		isLink: '',
			// 		isHide: false,
			// 		isKeepAlive: true,
			// 		isAffix: true,
			// 		isIframe: false,
			// 		roles: ['admin', 'common'],
			// 		icon: 'iconfont icon-shouye',
			// 		button:'121231'
			// 	},
			}
		],
	}
];


export const notFoundAndNoPower = [
	{
		path: '/:path(.*)*',
		name: 'notFound',
		component: () => import('/@/views/error/404.vue'),
		meta: {
			title: 'message.staticRoutes.notFound',
			isHide: true,
		},
	},
	{
		path: '/401',
		name: 'noPower',
		component: () => import('/@/views/error/401.vue'),
		meta: {
			title: 'message.staticRoutes.noPower',
			isHide: true,
		},
	},
];

export const staticRoutes: Array<RouteRecordRaw> = [
	{
		path: '/',
		name: '/',
		component: () => import('/@/layout/index.vue'),
		meta: {
			title: '布局界面',
		},
		children: [
			// 请不要往这里 `children` 中添加内容，此内容为了防止 No match found for location with path "xxx" 问题
			...notFoundAndNoPower,
		],
	},
	{
		path: '/login',
		name: 'login',
		component: () => import('/@/views/loginPage/loginPage.vue'),
		meta: {
			title: '登录',
		},
	},
	{
		path: '/homeMenu',
		name: 'homeMenu',
		component: () => import('/@/views/homeMenu/homeMenu.vue'),
		meta: {
			title: '目录',
		}
	},
	{
		path: '/workReservation',
		name: 'workReservation',
		component: () => import('/@/views/specialWorkSystem/workPlan/workReservation/index.vue'),
		meta: {
			title: '作业预约',
		},
	},
	{
		path: '/workAppointSummary',
		name: 'workAppointSummary',
		component: () => import('/@/views/specialWorkSystem/workPlan/workAppointSummary/index.vue'),
		meta: {
			title: '作业预约汇总',
		},
	},
	{
		path: '/approveProcessSetting',
		name: 'approveProcessSetting',
		component: () => import('/@/views/specialWorkSystem/approveProcessManagement/approveProcessSetting/index.vue'),
		meta: {
			title: '审批流程编辑',
		},
	},
	{
		path: '/reportTypeSetting',
		name: 'reportTypeSetting',
		component: () => import('/@/views/specialWorkSystem/approveProcessManagement/reportTypeSetting/index.vue'),
		meta: {
			title: '新建上报类型',
		},
	},
	{
		path: '/addApproveProcess',
		name: 'addApproveProcess',
		component: () => import('/@/views/specialWorkSystem/approveProcessManagement/addApproveProcess/index.vue'),
		meta: {
			title: '新建审批环节',
		},
	},
	{
		path: '/approveProcessList',
		name: 'approveProcessList',
		component: () => import('/@/views/specialWorkSystem/approveProcessManagement/approveProcessList/index.vue'),
		meta: {
			title: '审批流程管理',
		},
	},
	{
		path: '/workApplyForm',
		name: 'workApplyForm',
		component: () => import('/@/views/specialWorkSystem/workApplyManagement/workApplyForm/index.vue'),
		meta: {
			title: '作业申请表单',
		},
	},
	{
		path: '/myApply',
		name: 'myApply',
		component: () => import('/@/views/specialWorkSystem/workApplyManagement/myApply/index.vue'),
		meta: {
			title: '我的申请',
		},
	},
	{
		path: '/workCheckinRecord',
		name: 'workCheckinRecord',
		component: () => import('/@/views/specialWorkSystem/workProcessManagement/workCheckinRecord/index.vue'),
		meta: {
			title: '作业签到记录',
		},
	},
	{
		path: '/gasCheckAnalyze',
		name: 'gasCheckAnalyze',
		component: () => import('/@/views/specialWorkSystem/workProcessManagement/gasCheckAnalyze/index.vue'),
		meta: {
			title: '气体检查分析',
		},
	},
	{
		path: '/workTicketRecord',
		name: 'workTicketRecord',
		component: () => import('/@/views/specialWorkSystem/afterWorkManagement/workTicketRecord/index.vue'),
		meta: {
			title: '作业票归档记录',
		},
	},
	{
		path: '/workTicketCheck',
		name: 'workTicketCheck',
		component: () => import('/@/views/specialWorkSystem/afterWorkManagement/workTicketCheck/index.vue'),
		meta: {
			title: '作业票抽查',
		},
	},
	{
		path: '/workTypeSetting',
		name: 'workTypeSetting',
		component: () => import('/@/views/specialWorkSystem/workBasicManagementSetting/workTypeSetting/index.vue'),
		meta: {
			title: '作业工种设置',
		},
	},
	{
		path: '/certificateFilterSetting',
		name: 'certificateFilterSetting',
		component: () => import('/@/views/specialWorkSystem/workBasicManagementSetting/certificateFilterSetting/index.vue'),
		meta: {
			title: '证书过滤设置',
		},
	},
	{
		path: '/personalProtectDevices',
		name: 'personalProtectDevices',
		component: () => import('/@/views/specialWorkSystem/workBasicManagementSetting/personalProtectDevices/index.vue'),
		meta: {
			title: '个人防护用品库',
		},
	},
	{
		path: '/securityMeasuresManagement',
		name: 'securityMeasuresManagement',
		component: () => import('/@/views/specialWorkSystem/workBasicManagementSetting/securityMeasuresManagement/index.vue'),
		meta: {
			title: '安全措施管理',
		},
	}
];
